/********************************************************************
 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the "Company") for its PIC(R) Microcontroller is intended and
 supplied to you, the Company's customer, for use solely and
 exclusively on Microchip PIC Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *******************************************************************/

/** INCLUDES *******************************************************/
#include <system.h>
#include <system_config.h>

#include <usb/usb.h>
#include <usb/usb_device_hid.h>

#include <app_device_custom_hid.h>
#include <app_led_usb_status.h>




MAIN_RETURN main(void)
{
    uint16_t DataNoMax=50;
    int i;
    SYSTEM_Initialize(SYSTEM_STATE_USB_START);

    TRISE   =   0b00000011;         //SW1,2=INPUT LED=OUTPUT
    PORTEbits.RE2=0;//LED OFF
    PEIE = 0;// 周辺機能割込みの許可
    GIE = 0;// 全体の割込み許可

    while(PORTEbits.RE0==1 && PORTEbits.RE1==1){}

    if(PORTEbits.RE1==1)
    {
        DataNo=0;
        while(PORTEbits.RE1==1)
        {
            PORTEbits.RE2=1;//LED ON
            SetSendData();
            if(DataNo < DataNoMax){Write_EPROM(2*DataNo+8,SendData[1]);}
            __delay_ms( 5 ); //5mS
            if(DataNo < DataNoMax){Write_EPROM(2*DataNo+9,SendData[2]);}
            __delay_ms( 5 ); //5mS
            DataNo=DataNo+1;
            for(i=0;i<20;i++){__delay_ms( 10 );}
        }
        unsigned char    DataNo_H, DataNo_L;
        DataNo_L=DataNoMax;
        DataNo_H=DataNoMax >> 8;
        Write_EPROM(4,DataNo_H);
        __delay_ms( 5 ); //5mS
        Write_EPROM(5,DataNo_L);
        __delay_ms( 5 ); //5mS

        DataNo_L=DataNo;
        DataNo_H=DataNo >> 8;
        Write_EPROM(6,DataNo_H);
        __delay_ms( 5 ); //5mS
        Write_EPROM(7,DataNo_L);
        __delay_ms( 5 ); //5mS
    }

    PEIE = 1;// 周辺機能割込みの許可
    GIE = 1;// 全体の割込み許可

    USBDeviceInit();
    USBDeviceAttach();
    while(1)
    {
        PORTEbits.RE2=0;//LED OFF
        SYSTEM_Tasks();
        #if defined(USB_POLLING)
            // Interrupt or polling method.  If using polling, must call
            // this function periodically.  This function will take care
            // of processing and responding to SETUP transactions
            // (such as during the enumeration process when you first
            // plug in).  USB hosts require that USB devices should accept
            // and process SETUP packets in a timely fashion.  Therefore,
            // when using polling, this function should be called
            // regularly (such as once every 1.8ms or faster** [see
            // inline code comments in usb_device.c for explanation when
            // "or faster" applies])  In most cases, the USBDeviceTasks()
            // function does not take very long to execute (ex: <100
            // instruction cycles) before it returns.
            USBDeviceTasks();
        #endif

        /* If the USB device isn't configured yet, we can't really do anything
         * else since we don't have a host to talk to.  So jump back to the
         * top of the while loop. */
        if( USBGetDeviceState() < CONFIGURED_STATE )
        {
            /* Jump back to the top of the while loop. */
            continue;
        }

        /* If we are currently suspended, then we need to see if we need to
         * issue a remote wakeup.  In either case, we shouldn't process any
         * keyboard commands since we aren't currently communicating to the host
         * thus just continue back to the start of the while loop. */
        if( USBIsDeviceSuspended() == true )
        {
            /* Jump back to the top of the while loop. */
            continue;
        }

        //Application specific tasks
        APP_DeviceCustomHIDTasks();

    }//end while
}//end main


bool USER_USB_CALLBACK_EVENT_HANDLER(USB_EVENT event, void *pdata, uint16_t size)
{
    switch((int)event)
    {
        case EVENT_TRANSFER:
            break;

        case EVENT_SOF:
            /* We are using the SOF as a timer to time the LED indicator.  Call
             * the LED update function here. */
            APP_LEDUpdateUSBStatus();
            break;

        case EVENT_SUSPEND:
            /* Update the LED status for the suspend event. */
            APP_LEDUpdateUSBStatus();
            break;

        case EVENT_RESUME:
            /* Update the LED status for the resume event. */
            APP_LEDUpdateUSBStatus();
            break;

        case EVENT_CONFIGURED:
            /* When the device is configured, we can (re)initialize the demo
             * code. */
            APP_DeviceCustomHIDInitialize();
            break;

        case EVENT_SET_DESCRIPTOR:
            break;

        case EVENT_EP0_REQUEST:
            /* We have received a non-standard USB request.  The HID driver
             * needs to check to see if the request was for it. */
            USBCheckHIDRequest();
            break;

        case EVENT_BUS_ERROR:
            break;

        case EVENT_TRANSFER_TERMINATED:
            break;

        default:
            break;
    }
    return true;
}

void SetSendData()
{
    ADCON0	=	0b00000001; //A/D converter module is enabled:A/D Idle:Channel 0 (AN0)
    ADCON1  =	0b00001110; //AN0のみアナログ設定：VDDとVSSが選択
    TRISAbits.TRISA0 = 1; //RA0（AN0)を入力設定
    ADCON0bits.CHS = 0b0000; //Analog Channel Select bits=Channel 0 (AN0)
    ADCON0bits.GO = 1;              // Start AD conversion
    while(ADCON0bits.NOT_DONE);     // Wait for conversion


    SendData[0]=0x02;
    SendData[1]=ADRESH;//上位読込
    SendData[2]=ADRESL;//下位読込
}

void Write_EPROM(uint16_t addr,unsigned char send_data)
{
    TRISB   =	0b00000011; //B1=SCL(INPUT),BO=SDA(OUTPUT)I2C通信
    SSPCON1 = 0x28;		// SSP enable & I2C Master mode, clock = FOSC / (4 * (SSPADD+1))
    SSPADD = 0x0F;		// 0x00だと動作しないクロック設定
    
    unsigned char    addr1, addr2;
    addr2=addr;
    addr1=addr >> 8;

     //１バイト書込み
        PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
	SSPCON2bits.SEN = 1;//I2C_startビット
	while (SSPCON2bits.SEN) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};
	SSPBUF =0xA0;//0xA0 //書込み制御コード
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111110;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF = addr1; // 書き込みアドレス1
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111101;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF = addr2;// 書き込みアドレス2
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111100;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF =send_data;// send_data書き込み
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111011;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
	SSPCON2bits.PEN = 1;//I2C_通信終了
	while (SSPCON2bits.PEN) {}//終了待ち

}

unsigned char   Read_EPROM(uint16_t addr)
{
    TRISB   =	0b00000011; //B1=SCL(INPUT),BO=SDA(OUTPUT)I2C通信
    SSPCON1 = 0x28;		// SSP enable & I2C Master mode, clock = FOSC / (4 * (SSPADD+1))
    SSPADD = 0x0F;		// 0x00だと動作しないクロック設定

    unsigned char    addr1, addr2;
    unsigned char data=5;


    addr2=addr;
    addr1=addr >> 8;

    //１バイト読込
        PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
	SSPCON2bits.SEN = 1;//I2C_startビット
	while (SSPCON2bits.SEN) {}

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF =0xA0;//0xA0//書込み制御コード
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111010;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF = addr1;// 書き込みアドレス1
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111001;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF = addr2; // 書き込みアドレス2
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11111000;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	SSPCON2bits.SEN = 1;//I2C_startビット
	while (SSPCON2bits.SEN) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        while(SSPSTATbits.BF){};//SSPBUFの干渉確認
	SSPBUF =  0xA1; //0xA1 //読込制御コード
        if (SSPCON2bits.ACKSTAT) {PORTD=0b11110111;}//ACKチェック
	while (!PIR1bits.SSPIF) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
	SSPCON2bits.RCEN = 1;//受信モードを動作
	while (SSPCON2bits.RCEN) {}//終了待ち

	data=SSPBUF;//受信コピー

        PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
        SSPCON2bits.ACKDT = 1;//受信の終わりで応答シーケンスを開始1=NO-ACK
        SSPCON2bits.ACKEN = 1;//、ACKDT データビットを送信する。
	while (SSPCON2bits.ACKEN) {}//終了待ち

	PIR1bits.SSPIF = 0;//I2C_通信割込みフラグクリア
	SSPCON2bits.PEN = 1;//I2C_通信終了
	while (SSPCON2bits.PEN) {}//終了待ち

    return data;
}

/*******************************************************************************
 End of File
*/

